#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from abc import ABC, abstractmethod

from immutable_views import DictView


class MessageArchitectIF(ABC):
    """
    Generic methods to build AMQP Messages
    """

    @staticmethod
    @abstractmethod
    def get_message_template(msg_type: str) -> DictView:
        """
        Retrieves a DictView of the template for the message type provided
        :param msg_type: type of message to send
        :return: template DictView
        """
        raise NotImplementedError

    @abstractmethod
    def compose_message(self, msg_type: str) -> DictView:
        """
        Uses a templated message to construct a real AMQP message and returns it
        :param msg_type: type of message to send
        :return: message DictView
        """
        raise NotImplementedError
